Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(703)

Unified Diff: Source/core/frame/animation/AnimationBase.cpp

Issue 27030009: Revert "Make compositingState explicit (re-land #2 with bogus ASSERT removed)" (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: fix build error Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/frame/FrameView.cpp ('k') | Source/core/frame/animation/ImplicitAnimation.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/frame/animation/AnimationBase.cpp
diff --git a/Source/core/frame/animation/AnimationBase.cpp b/Source/core/frame/animation/AnimationBase.cpp
index 5cbd4aaf9685a8ed658dc8367c348c84a86ffa5b..4e3356c7fa1bfefb692b4be96160b5ac61d83293 100644
--- a/Source/core/frame/animation/AnimationBase.cpp
+++ b/Source/core/frame/animation/AnimationBase.cpp
@@ -555,9 +555,8 @@ void AnimationBase::freezeAtTime(double t)
else
m_pauseTime = m_startTime + t - m_animation->delay();
- // It is possible that m_isAccelerated is true and m_object->compositingState() is NotComposited, because of style change.
- // So, both conditions need to be checked.
- if (m_object && m_object->compositingState() == PaintsIntoOwnBacking && isAccelerated())
+ // It is possible that m_isAccelerated is true and m_object->isComposited() is false, because of style change.
+ if (m_object && m_object->isComposited() && isAccelerated())
toRenderBoxModelObject(m_object)->suspendAnimations(m_pauseTime);
}
« no previous file with comments | « Source/core/frame/FrameView.cpp ('k') | Source/core/frame/animation/ImplicitAnimation.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698